From aef696eeab7a0a8122e9da3021b4310674539bb9 Mon Sep 17 00:00:00 2001
From: Phil Elwell <phil@raspberrypi.com>
Date: Tue, 5 May 2020 19:45:41 +0100
Subject: [PATCH] video: bcm2708_fb: Disable FB if no displays found

If the firmware hasn't detected a display, the driver would assume
one display was available, but because it had failed to retrieve the
display size it would try to allocate a zero-sized buffer.

Avoid the allocation failure by bailing out early if no display is
found.

See: https://github.com/raspberrypi/linux/issues/3598

Signed-off-by: Phil Elwell <phil@raspberrypi.com>
---
 drivers/video/fbdev/bcm2708_fb.c | 5 ++---
 1 file changed, 2 insertions(+), 3 deletions(-)

--- a/drivers/video/fbdev/bcm2708_fb.c
+++ b/drivers/video/fbdev/bcm2708_fb.c
@@ -1092,10 +1092,9 @@ static int bcm2708_fb_probe(struct platf
 	 * set one display
 	 */
 	if (ret || num_displays == 0) {
-		num_displays = 1;
 		dev_err(&dev->dev,
-			"Unable to determine number of FB's. Assuming 1\n");
-		ret = 0;
+			"Unable to determine number of FBs. Disabling driver.\n");
+		return -ENOENT;
 	} else {
 		fbdev->firmware_supports_multifb = 1;
 	}
